@@ -324,7 +324,7 @@ module Kramdown
 
     def rfc2629_fix(opts)
       if a = attr
-        if anchor = a.delete('id')
+        if !opts[:noanchor] && (anchor = a.delete('id'))
           a['anchor'] = ::Kramdown::Parser::RFC2629Kramdown.idref_cleanup(anchor)
         end
         if anchor = a.delete('href')
@@ -751,7 +751,10 @@ COLORS
             "#{' '*indent}<figure#{el_html_attributes(el)}>#{retart}</figure>\n"
           else
             gi ||= (
-              if !$options.v3 || !t || ARTWORK_TYPES.include?(t) || artwork_attr["align"]
+              if !$options.v3 || !t || ARTWORK_TYPES.include?(t)
+                "artwork"
+              elsif artwork_attr["align"]
+                warn "** RFXCMLv3 does not yet allow setting align= for <sourcecode, falling back to <artwork"
                 "artwork"
               else
                 "sourcecode"
@@ -1043,6 +1046,9 @@ COLORS
       HTML_TAGS_WITH_BODY=['div', 'script']
 
       def convert_html_element(el, indent, opts)
+        if el.value == "svg"    # do not meddle with id= in SVG
+          opts = opts.merge({noanchor: true})
+        end
         res = inner(el, indent, opts)
         if el.options[:category] == :span
           "<#{el.value}#{el_html_attributes(el)}" << (!res.empty? ? ">#{res}</#{el.value}>" : " />")
@@ -1560,17 +1566,19 @@ COLORS
 
         else
           type = 'spanx'
-          if $options.v3
-            type = 'contact'
-            result = munge_latex(el.value)
-            attrstring = el_html_attributes_with(el, {"fullname" => result.chomp, "asciiFullname" => ''})
+          if $options.v3        # could use utftex if present
+            content = escape_html(munge_latex(el.value).chomp, :text)
+            attrstring = el_html_attributes_with(el, {"style" => 'none'})
           else
             warn "*** no support for inline math in XML2RFCv2"
-            type = 'spanx'
-            attrstring = el_html_attributes_with(el, {"style" => 'verb'})
             content = escape_html(el.value, :text)
+            attrstring = el_html_attributes_with(el, {"style" => 'verb'})
+          end
+          if attrstring == ' style="none"'
+            content
+          else
+            "<#{type}#{attrstring}>#{content}</#{type}>" # this might get a style=none...
           end
-          "<#{type}#{attrstring}>#{content}</#{type}>"
         end
       end
 
